You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@mesos.apache.org by ka...@apache.org on 2017/08/18 17:38:11 UTC

[1/7] mesos git commit: Updated endpoints help docs.

Repository: mesos
Updated Branches:
  refs/heads/1.4.x 25e75de35 -> b9187d54a


Updated endpoints help docs.

Review: https://reviews.apache.org/r/61732


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/64335de8
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/64335de8
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/64335de8

Branch: refs/heads/1.4.x
Commit: 64335de8826b6e9ab6408f1756c9130aea0a8886
Parents: b4516b8
Author: Kapil Arya <ka...@mesosphere.io>
Authored: Thu Aug 17 22:30:17 2017 -0400
Committer: Kapil Arya <ka...@mesosphere.io>
Committed: Fri Aug 18 13:36:35 2017 -0400

----------------------------------------------------------------------
 docs/endpoints/index.md                         |  1 +
 docs/endpoints/master/frameworks.md             |  3 +++
 docs/endpoints/master/slaves.md                 |  3 +++
 docs/endpoints/master/tasks.json.md             |  2 ++
 docs/endpoints/master/tasks.md                  |  2 ++
 .../endpoints/slave/api/v1/resource_provider.md | 28 ++++++++++++++++++++
 6 files changed, 39 insertions(+)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/64335de8/docs/endpoints/index.md
----------------------------------------------------------------------
diff --git a/docs/endpoints/index.md b/docs/endpoints/index.md
index eb88154..8711537 100644
--- a/docs/endpoints/index.md
+++ b/docs/endpoints/index.md
@@ -115,6 +115,7 @@ For example, `http://agent.com:5051/files/browse`.
 ### slave(id) ###
 * [/api/v1](slave/api/v1.md)
 * [/api/v1/executor](slave/api/v1/executor.md)
+* [/api/v1/resource_provider](slave/api/v1/resource_provider.md)
 * [/containers](slave/containers.md)
 * [/flags](slave/flags.md)
 * [/health](slave/health.md)

http://git-wip-us.apache.org/repos/asf/mesos/blob/64335de8/docs/endpoints/master/frameworks.md
----------------------------------------------------------------------
diff --git a/docs/endpoints/master/frameworks.md b/docs/endpoints/master/frameworks.md
index 1a7950a..7aa2213 100644
--- a/docs/endpoints/master/frameworks.md
+++ b/docs/endpoints/master/frameworks.md
@@ -20,6 +20,9 @@ current master is not the leader.
 Returns 503 SERVICE_UNAVAILABLE if the leading master cannot be
 found.
 
+Query parameters:
+>        framework_id=VALUE   The ID of the framework returned (if no framework ID is specified, all frameworks will be returned).
+
 
 ### AUTHENTICATION ###
 This endpoint requires authentication iff HTTP authentication is

http://git-wip-us.apache.org/repos/asf/mesos/blob/64335de8/docs/endpoints/master/slaves.md
----------------------------------------------------------------------
diff --git a/docs/endpoints/master/slaves.md b/docs/endpoints/master/slaves.md
index f9bb7ef..9365cdb 100644
--- a/docs/endpoints/master/slaves.md
+++ b/docs/endpoints/master/slaves.md
@@ -24,6 +24,9 @@ This endpoint shows information about the agents which are registered
 in this master or recovered from registry, formatted as a JSON
 object.
 
+Query parameters:
+>        slave_id=VALUE       The ID of the slave returned (when no slave_id is specified, all slaves will be returned).
+
 
 ### AUTHENTICATION ###
 This endpoint requires authentication iff HTTP authentication is

http://git-wip-us.apache.org/repos/asf/mesos/blob/64335de8/docs/endpoints/master/tasks.json.md
----------------------------------------------------------------------
diff --git a/docs/endpoints/master/tasks.json.md b/docs/endpoints/master/tasks.json.md
index f6b808d..f9553d7 100644
--- a/docs/endpoints/master/tasks.json.md
+++ b/docs/endpoints/master/tasks.json.md
@@ -26,9 +26,11 @@ accessing the endpoint.
 
 Query parameters:
 
+>        framework_id=VALUE   Only return tasks belonging to the framework with this ID.
 >        limit=VALUE          Maximum number of tasks returned (default is 100).
 >        offset=VALUE         Starts task list at offset.
 >        order=(asc|desc)     Ascending or descending sort order (default is descending).
+>        task_id=VALUE        Only return tasks with this ID (should be used together with parameter 'framework_id').
 
 
 ### AUTHENTICATION ###

http://git-wip-us.apache.org/repos/asf/mesos/blob/64335de8/docs/endpoints/master/tasks.md
----------------------------------------------------------------------
diff --git a/docs/endpoints/master/tasks.md b/docs/endpoints/master/tasks.md
index da04c9f..019a14b 100644
--- a/docs/endpoints/master/tasks.md
+++ b/docs/endpoints/master/tasks.md
@@ -26,9 +26,11 @@ accessing the endpoint.
 
 Query parameters:
 
+>        framework_id=VALUE   Only return tasks belonging to the framework with this ID.
 >        limit=VALUE          Maximum number of tasks returned (default is 100).
 >        offset=VALUE         Starts task list at offset.
 >        order=(asc|desc)     Ascending or descending sort order (default is descending).
+>        task_id=VALUE        Only return tasks with this ID (should be used together with parameter 'framework_id').
 
 
 ### AUTHENTICATION ###

http://git-wip-us.apache.org/repos/asf/mesos/blob/64335de8/docs/endpoints/slave/api/v1/resource_provider.md
----------------------------------------------------------------------
diff --git a/docs/endpoints/slave/api/v1/resource_provider.md b/docs/endpoints/slave/api/v1/resource_provider.md
new file mode 100644
index 0000000..c721c6d
--- /dev/null
+++ b/docs/endpoints/slave/api/v1/resource_provider.md
@@ -0,0 +1,28 @@
+---
+title: Apache Mesos - HTTP Endpoints - /api/v1/resource_provider
+layout: documentation
+---
+<!--- This is an automatically generated file. DO NOT EDIT! --->
+
+### USAGE ###
+>        /api/v1/resource_provider
+>        /slave(1)/api/v1/resource_provider
+
+### TL;DR; ###
+Endpoint for the local resource provider HTTP API.
+
+### DESCRIPTION ###
+This endpoint is used by the local resource providers to interact
+with the agent via Call/Event messages.
+
+Returns 200 OK iff the initial SUBSCRIBE Call is successful. This
+will result in a streaming response via chunked transfer encoding.
+The local resource providers can process the response incrementally.
+
+Returns 202 Accepted for all other Call messages iff the request is
+accepted.
+
+
+### AUTHENTICATION ###
+This endpoint requires authentication iff HTTP authentication is
+enabled.
\ No newline at end of file


[5/7] mesos git commit: Updated configuration.md to reflect new flags.

Posted by ka...@apache.org.
Updated configuration.md to reflect new flags.

Review: https://reviews.apache.org/r/61731


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/6fa53273
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/6fa53273
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/6fa53273

Branch: refs/heads/1.4.x
Commit: 6fa53273978d5521ce17abca7e569d4dc95c96aa
Parents: 27379a7
Author: Kapil Arya <ka...@mesosphere.io>
Authored: Fri Aug 18 08:32:03 2017 -0400
Committer: Kapil Arya <ka...@mesosphere.io>
Committed: Fri Aug 18 13:36:35 2017 -0400

----------------------------------------------------------------------
 docs/configuration.md | 49 ++++++++++++++++++++++++++++++++++++++++++++++
 1 file changed, 49 insertions(+)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/6fa53273/docs/configuration.md
----------------------------------------------------------------------
diff --git a/docs/configuration.md b/docs/configuration.md
index e43f9ea..c149339 100644
--- a/docs/configuration.md
+++ b/docs/configuration.md
@@ -212,6 +212,33 @@ Cannot be used in conjunction with <code>--ip</code>.
 </tr>
 <tr>
   <td>
+    --ip6=VALUE
+  </td>
+  <td>
+IPv6 address to listen on. This cannot be used in conjunction
+with <code>--ip6_discovery_command</code>.
+<p/>
+NOTE: Currently Mesos doesn't listen on IPv6 sockets and hence
+this IPv6 address is only used to advertise IPv6 addresses for
+containers running on the host network.
+  </td>
+</tr>
+<tr>
+  <td>
+    --ip6_discovery_command=VALUE
+  </td>
+  <td>
+Optional IPv6 discovery binary: if set, it is expected to emit
+the IPv6 address on which Mesos will try to bind when IPv6 socket
+support is enabled in Mesos.
+<p/>
+NOTE: Currently Mesos doesn't listen on IPv6 sockets and hence
+this IPv6 address is only used to advertise IPv6 addresses for
+containers running on the host network.
+  </td>
+</tr>
+<tr>
+  <td>
     --modules=VALUE
   </td>
   <td>
@@ -1649,6 +1676,16 @@ terminations may occur.
   <td>
 Parent directory for fetcher cache directories
 (one subdirectory per agent). (default: /tmp/mesos/fetch)
+
+Directory for the fetcher cache. The agent will clear this directory
+on startup. It is recommended to set this value to a separate volume
+for several reasons:
+<ul>
+<li> The cache directories are transient and not meant to be
+     backed up. Upon restarting the agent, the cache is always empty. </li>
+<li> The cache and container sandboxes can potentially interfere with
+     each other when occupying a shared space (i.e. disk contention). </li>
+</ul>
   </td>
 </tr>
 <tr>
@@ -2073,6 +2110,18 @@ state as possible is recovered.
 </tr>
 <tr>
   <td>
+    --secret_resolver=VALUE
+  </td>
+  <td>
+The name of the secret resolver module to use for resolving
+environment and file-based secrets. If this flag is not specified,
+the default behavior is to resolve value-based secrets and error on
+reference-based secrets.
+  </td>
+</tr>
+
+<tr>
+  <td>
     --[no-]switch_user
   </td>
   <td>


[4/7] mesos git commit: Removed diacritics from docs/health-checks.md.

Posted by ka...@apache.org.
Removed diacritics from docs/health-checks.md.

Review: https://reviews.apache.org/r/61735/


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/7bdab76f
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/7bdab76f
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/7bdab76f

Branch: refs/heads/1.4.x
Commit: 7bdab76f1a0aa30830abb0d88ddbdf1f7706fc89
Parents: 25e75de
Author: Till Toenshoff <to...@me.com>
Authored: Fri Aug 18 16:58:02 2017 +0200
Committer: Kapil Arya <ka...@mesosphere.io>
Committed: Fri Aug 18 13:36:35 2017 -0400

----------------------------------------------------------------------
 docs/health-checks.md | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/7bdab76f/docs/health-checks.md
----------------------------------------------------------------------
diff --git a/docs/health-checks.md b/docs/health-checks.md
index 41fc4f8..b9b6327 100644
--- a/docs/health-checks.md
+++ b/docs/health-checks.md
@@ -75,7 +75,7 @@ status updates are triggered if a certain condition is met, e.g., the value or
 presence of a specific field in the check status changes.
 
 When a built-in executor sends a task status update because the check or health
-check status has changed, it sets `TaskStatus.reason` to
+check status has changed, it sets `TaskStatus.reason` to
 `REASON_TASK_CHECK_STATUS_UPDATED` or `REASON_TASK_HEALTH_CHECK_STATUS_UPDATED`
 respectively. While sending such an update, the executor avoids shadowing other
 data that might have been injected previously, e.g., a check update includes the
@@ -99,11 +99,11 @@ implementation for health checking that all built-in executors rely on.
 ### On the Differences Between Checks and Health Checks
 When humans read data from a sensor, they may interpret these data and act on
 them. For example, if they check air temperature, they usually interpret
-temperature readings and say whether it’s cold or warm outside; they may also
+temperature readings and say whether it's cold or warm outside; they may also
 act on the interpretation and decide to apply sunscreen or put on an extra
 jacket.
 
-Similar reasoning can be applied to checking task’s state in Mesos:
+Similar reasoning can be applied to checking task's state in Mesos:
 
 1. Perform a check.
 2. Optionally interpret the result and, for example, declare the task either
@@ -114,7 +114,7 @@ Mesos health checks do all of the above, 1+2+3: they run the check, declare the
 task healthy or not, and kill it after `consecutive_failures` have occurred.
 Though efficient and scalable, this strategy is inflexible for the needs of
 frameworks which may want to run an arbitrary check without Mesos interpreting
-the result in any way, for example, to transmit the task’s internal state
+the result in any way, for example, to transmit the task's internal state
 transitions and make global decisions.
 
 Conceptually, a health check is a check with an interpretation and a kill


[3/7] mesos git commit: Added secrets docs.

Posted by ka...@apache.org.
Added secrets docs.

Review: https://reviews.apache.org/r/61725


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/27379a79
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/27379a79
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/27379a79

Branch: refs/heads/1.4.x
Commit: 27379a790145fd9ccfbefca7294e0e4de06e2976
Parents: 7bdab76
Author: Kapil Arya <ka...@mesosphere.io>
Authored: Thu Aug 17 21:28:19 2017 -0400
Committer: Kapil Arya <ka...@mesosphere.io>
Committed: Fri Aug 18 13:36:35 2017 -0400

----------------------------------------------------------------------
 docs/home.md    |   1 +
 docs/secrets.md | 148 +++++++++++++++++++++++++++++++++++++++++++++++++++
 2 files changed, 149 insertions(+)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/27379a79/docs/home.md
----------------------------------------------------------------------
diff --git a/docs/home.md b/docs/home.md
index ab32838..ad91f2f 100644
--- a/docs/home.md
+++ b/docs/home.md
@@ -35,6 +35,7 @@ layout: documentation
 * [Monitoring](monitoring.md)
 * [Operational Guide](operational-guide.md)
 * [Roles](roles.md)
+* [Secrets](secrets.md) for managing secrets within Mesos.
 * [SSL](ssl.md) for enabling and enforcing SSL communication.
 * [Nested Container and Task Group (Pod)](nested-container-and-task-group.md)
 * [Tools](tools.md) for setting up and running a Mesos cluster.

http://git-wip-us.apache.org/repos/asf/mesos/blob/27379a79/docs/secrets.md
----------------------------------------------------------------------
diff --git a/docs/secrets.md b/docs/secrets.md
new file mode 100644
index 0000000..ce5341a
--- /dev/null
+++ b/docs/secrets.md
@@ -0,0 +1,148 @@
+---
+title: Apache Mesos - Secrets Handling
+layout: documentation
+---
+
+# Secrets
+Starting 1.4.0 release, Mesos allows tasks to populate environment variables and
+file volumes with secret contents that are retrieved using a secret-resolver
+interface. It also allows specifying image-pull secrets for private container
+registry. This allows users to avoid exposing critical secrets in task
+definitions. Secrets are fetched/resolved using a secret-resolver module (see
+below).
+
+NOTE: Secrets are only supported for Mesos containerizer and not for the Docker
+containerizer.
+
+## Secrets Message
+Secrets can be specified using the following protobuf message:
+
+```
+message Secret {
+  enum Type {
+    UNKNOWN = 0;
+    REFERENCE = 1;
+    VALUE = 2;
+  }
+
+  message Reference {
+    required string name = 1;
+    optional string key = 2;
+  }
+
+  message Value {
+    required bytes data = 1;
+  }
+
+  optional Type type = 1;
+
+  optional Reference reference = 2;
+  optional Value value = 3;
+}
+```
+
+Secrets can be of type `reference` or `value` (only one of `reference` and `value` must be set).
+A secret reference can be used by modules to refer to a secret stored in a secure back-end.
+The `key` field can be used to reference a single value within a secret containing arbitrary key-value pairs.
+
+For example, given a back-end secret store with a secret named "/my/secret" containing the following key-value pairs:
+
+```
+{
+  "username": "my-user",
+  "password": "my-password
+}
+```
+
+The username could be referred to in a `Secret` by specifying "my/secret" for the `name` and "username" for the `key`.
+
+Secret also supports pass-by-value where the value of a secret can be directly
+passed in the message.
+
+## Environment-based Secrets
+Environment variables can either be traditional value-based or secret-based. For
+the latter, one can specify a secret as part of environment definition as shown
+in the following example:
+
+```
+{
+  "variables" : [
+    {
+      "name": "MY_SECRET_ENV",
+      "type": "SECRET",
+      "secret": {
+        "type": "REFERENCE",
+        "reference": {
+          "name": "/my/secret",
+          "key": "username"
+        }
+      }
+    },
+    {
+      "name": "MY_NORMAL_ENV",
+      "value": "foo"
+    }
+  ]
+}
+```
+
+## File-based Secrets
+A new `volume/secret` isolator is available to create secret-based files inside
+the task container. To use a secret, one can specify a new volume as follows:
+
+```
+{
+  "mode": "RW",
+  "container_path": "path/to/secret/file",
+  "source":
+  {
+    "type": "SECRET",
+    "secret": {
+      "type": "REFERENCE",
+      "reference": {
+        "name": "/my/secret",
+        "key": "username"
+      }
+    }
+  }
+}
+```
+
+This will create a tmpfs-based file mount in the container at "path/to/secret/file" which will contain the secret text fetched from the back-end secret store.
+
+The `volume/secret` isolator is not enabled by default. To enable it, it must be specified in `--isolator=volume/secret` agent flag.
+
+## Image-pull Secrets
+Currently, image-pull secrets only support Docker images for Mesos
+containerizer. Appc images are not supported.
+One can store Docker config containing credentials to authenticate with Docker registry in the secret store.
+The secret is expected to be a Docker config file in JSON format with UTF-8 character encoding.
+The secret can then be referenced in the `Image` protobuf as follows:
+
+```
+{
+  "type": "DOCKER",
+  "docker":
+  message Docker {
+    "name": "<REGISTRY_HOST>/path/to/image",
+    "secret": {
+      "type": "REFERENCE",
+      "reference": {
+        "name": "/my/secret/docker/config"
+      }
+    }
+  }
+}
+```
+
+## SecretResolver Module
+The SecretResolver module is called from Mesos agent to fetch/resolve any image-pull, environment-based, or file-based secrets. (See [Mesos Modules](modules.md) for more information on using Mesos modules).
+
+```
+class SecretResolver
+{
+  virtual process::Future<Secret::Value> resolve(const Secret& secret) const;
+};
+```
+
+The default implementation simply resolves value-based Secrets. A custom secret-resolver module can be specified using the `--secret_resolver=<module-name>` agent flag.


[6/7] mesos git commit: Synchronized comment in v1 and unversioned master.proto.

Posted by ka...@apache.org.
Synchronized comment in v1 and unversioned master.proto.

Review: https://reviews.apache.org/r/61733


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/9dd08ece
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/9dd08ece
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/9dd08ece

Branch: refs/heads/1.4.x
Commit: 9dd08ece26532985d8ff041c3f93a6c543cbfe57
Parents: 6fa5327
Author: Kapil Arya <ka...@mesosphere.io>
Authored: Fri Aug 18 09:19:15 2017 -0400
Committer: Kapil Arya <ka...@mesosphere.io>
Committed: Fri Aug 18 13:36:35 2017 -0400

----------------------------------------------------------------------
 include/mesos/v1/master/master.proto | 16 +++++++---------
 1 file changed, 7 insertions(+), 9 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/9dd08ece/include/mesos/v1/master/master.proto
----------------------------------------------------------------------
diff --git a/src/master/http.cpp b/src/master/http.cpp
index 959091c..5654e7e 100644
--- a/src/master/http.cpp
+++ b/src/master/http.cpp
@@ -1498,7 +1498,7 @@ string Master::Http::FRAMEWORKS_HELP()
         "",
         "Query parameters:",
         ">        framework_id=VALUE   The ID of the framework returned "
-        "(when no framework ID specified, all frameworks will be returned)."),
+        "(if no framework ID is specified, all frameworks will be returned)."),
     AUTHENTICATION(true),
     AUTHORIZATION(
         "This endpoint might be filtered based on the user accessing it.",

http://git-wip-us.apache.org/repos/asf/mesos/blob/b4516b8a/src/slave/http.cpp
----------------------------------------------------------------------
diff --git a/src/slave/http.cpp b/src/slave/http.cpp
index 544a052..a828c5f 100644
--- a/src/slave/http.cpp
+++ b/src/slave/http.cpp
@@ -812,7 +812,7 @@ Future<Response> Http::executor(
 string Http::RESOURCE_PROVIDER_HELP() {
   return HELP(
     TLDR(
-        "Endpoint for the Local Resource Provider HTTP API."),
+        "Endpoint for the local resource provider HTTP API."),
     DESCRIPTION(
         "This endpoint is used by the local resource providers to interact",
         "with the agent via Call/Event messages.",


[7/7] mesos git commit: Removed WIP from CHANGELOG.

Posted by ka...@apache.org.
Removed WIP from CHANGELOG.

Added image-pull secrets.


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/b9187d54
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/b9187d54
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/b9187d54

Branch: refs/heads/1.4.x
Commit: b9187d54a97206b4a09fb5cb1d0834ab5fa5abd3
Parents: 64335de
Author: Kapil Arya <ka...@mesosphere.io>
Authored: Thu Aug 17 22:19:18 2017 -0400
Committer: Kapil Arya <ka...@mesosphere.io>
Committed: Fri Aug 18 13:37:34 2017 -0400

----------------------------------------------------------------------
 CHANGELOG | 9 +++++----
 1 file changed, 5 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/b9187d54/CHANGELOG
----------------------------------------------------------------------
diff --git a/CHANGELOG b/CHANGELOG
index 2382d15..8528fc0 100644
--- a/CHANGELOG
+++ b/CHANGELOG
@@ -1,4 +1,4 @@
-Release Notes - Mesos - Version 1.4.0 (WIP)
+Release Notes - Mesos - Version 1.4.0
 -------------------------------------------
 This release contains the following new features:
 
@@ -18,9 +18,9 @@ This release contains the following new features:
     hierarchical roles, see: MESOS-7402) and thus it is not recommended
     for production usage at this time.
 
-  * [MESOS-7418] - File-based secrets are now supported for Mesos and Universal
-    containerizer. One can specify a file volume which can be populated with
-    secret contents. The secret file is mounted as tmpfs inside the container.
+  * [MESOS-7418, MESOS-7088] - File-based secrets are now supported for Mesos
+    and Universal containerizer. Image-pull secrets are supported for Docker
+    registry credentials.
 
   * [MESOS-7477] - Linux ambient capabilites are now supported, so
     frameworks can run tasks that use ambient capabilites to grant
@@ -169,6 +169,7 @@ All Resolved Issues:
     * [MESOS-7501] - Change legacy --with-network-isolator to --with-port-mapping-isolator
 
 ** Epic
+    * [MESOS-7088] - Support private registry credential per container.
     * [MESOS-6975] - Prevent pre-1.0 agents from registering with 1.3+ master.
     * [MESOS-7623] - Automatically publish website through CI
diff --git a/include/mesos/v1/master/master.proto b/include/mesos/v1/master/master.proto
index c3fb31d..4ded0a8 100644
--- a/include/mesos/v1/master/master.proto
+++ b/include/mesos/v1/master/master.proto
@@ -360,7 +360,7 @@ message Response {
     // `recovered` field set to true.
     //
     // TODO(neilc): Remove this field in Mesos 2.0.
-    repeated FrameworkInfo recovered_frameworks = 3;
+    repeated FrameworkInfo recovered_frameworks = 3 [deprecated=true];
   }
 
   // Lists information about all the executors known to the master at the
@@ -374,11 +374,10 @@ message Response {
 
     repeated Executor executors = 1;
 
     // As of Mesos 1.2, this field will always be empty.
     //
-    // TODO(neilc): Remove this field after a deprecation cycle starting
-    // in Mesos 1.2.
-    repeated Executor orphan_executors = 2;
+    // TODO(neilc): Remove this field in Mesos 2.0.
+    repeated Executor orphan_executors = 2 [deprecated=true];
   }
 
   // Lists information about all the tasks known to the master at the current
@@ -407,11 +406,10 @@ message Response {
     // acknowledged by the scheduler.
     repeated Task completed_tasks = 3;
 
     // As of Mesos 1.2, this field will always be empty.
     //
-    // TODO(neilc): Remove this field after a deprecation cycle starting
-    // in Mesos 1.2.
-    repeated Task orphan_tasks = 4;
+    // TODO(neilc): Remove this field in Mesos 2.0.
+    repeated Task orphan_tasks = 4 [deprecated=true];
   }
 
   // Provides information about every role that is on the role whitelist (if


[2/7] mesos git commit: Fixed capitalization and typos in endpoint helps.

Posted by ka...@apache.org.
Fixed capitalization and typos in endpoint helps.

Review: https://reviews.apache.org/r/61745


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/b4516b8a
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/b4516b8a
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/b4516b8a

Branch: refs/heads/1.4.x
Commit: b4516b8a6644ba5147c7cf275387e882417de5ce
Parents: 9dd08ec
Author: Kapil Arya <ka...@mesosphere.io>
Authored: Fri Aug 18 13:06:45 2017 -0400
Committer: Kapil Arya <ka...@mesosphere.io>
Committed: Fri Aug 18 13:36:35 2017 -0400

----------------------------------------------------------------------
 src/master/http.cpp | 2 +-
 src/slave/http.cpp  | 2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/b4516b8a/src/master/http.cpp
----------------------------------------------------------------------
@@ -374,11 +374,10 @@ message Response {
     repeated Executor executors = 1;
 
-    // As of Mesos 1.2, this field will always be empty.
+    // As of Mesos 1.3.0, this field is deprecated and will always be empty.
     //
@@ -407,11 +406,10 @@ message Response {
     repeated Task completed_tasks = 3;
 
-    // As of Mesos 1.2, this field will always be empty.
+    // As of Mesos 1.3.0, this field is deprecated and will always be empty.
     //